# frozen_string_literal: true

require_relative './prometheus/configuration'

module Invoca
  module Metrics
    module Prometheus
      class NotConfiguredError < StandardError; end

      class << self
        # This method is used to configure Invoca::Metrics to export metrics to be
        # pulled into Prometheus.
        #
        # @yield [Invoca::Metrics::Prometheus::Configuration]
        #
        # @void
        def configure
          @config = Invoca::Metrics::Prometheus::Configuration.new.tap { |config| yield config }.freeze
        end

        # Accessor for the existing Prometheus configuration
        #
        # @raise [Invoca::Metrics::Prometheus::NotConfiguredError]
        # @return [Invoca::Metrics::Prometheus::Configuration]
        def config
          @config or raise NotConfiguredError, 'Invoca::Metrics::Prometheus is trying to be used without being configured'
        end
      end
    end
  end
end
